@@ -12,13 +12,16 @@
 #define MISC_TABLE_DRIVEN_LSC_H
 
 #include <glib.h>
+#include <gvm/util/kb.h> // for kb_t
 
-gchar *
-make_table_driven_lsc_info_json_str (const char *, const char *, const char *,
-                                     const char *, const char *);
+void
+set_lsc_flag (void);
 
-gchar *
-get_status_of_table_driven_lsc_from_json (const char *, const char *,
-                                          const char *, int);
+int
+lsc_has_run (void);
+
+int
+run_table_driven_lsc (const char *, const char *, const char *, const char *,
+                      const char *);
 
 #endif // MISC_TABLE_DRIVEN_LSC_H
