@@ -21,7 +21,9 @@
 #include "nasl_global_ctxt.h"
 #include "nasl_host.h"
 #include "nasl_http.h"
+#include "nasl_http2.h"
 #include "nasl_isotime.h"
+#include "nasl_krb5.h"
 #include "nasl_lex_ctxt.h"
 #include "nasl_misc_funcs.h"
 #include "nasl_packet_forgery.h"
@@ -77,6 +79,7 @@ static init_func libfuncs[] = {
   {"script_xref", script_xref},
   {"script_tag", script_tag},
   {"vendor_version", nasl_vendor_version},
+  {"update_table_driven_lsc_data", nasl_update_table_driven_lsc_data},
   {"get_preference", nasl_get_preference},
   {"safe_checks", safe_checks},
   {"get_script_oid", get_script_oid},
@@ -87,7 +90,7 @@ static init_func libfuncs[] = {
   {"get_host_kb_index", get_host_kb_index},
   {"security_message", security_message},
   {"log_message", log_message},
-  {"error_message", error_message},
+  {"error_message", error_message2},
   {"open_sock_tcp", nasl_open_sock_tcp},
   {"open_sock_udp", nasl_open_sock_udp},
   {"open_priv_sock_tcp", nasl_open_priv_sock_tcp},
@@ -119,8 +122,18 @@ static init_func libfuncs[] = {
   {"http_delete", http_delete},
   {"http_put", http_put},
   {"http_close_socket", http_close_socket},
+  {"http2_handle", nasl_http2_handle},
+  {"http2_get_response_code", nasl_http2_get_response_code},
+  {"http2_close_handle", nasl_http2_close_handle},
+  {"http2_set_custom_header", nasl_http2_set_custom_header},
+  {"http2_get", nasl_http2_get},
+  {"http2_head", nasl_http2_head},
+  {"http2_post", nasl_http2_post},
+  {"http2_delete", nasl_http2_delete},
+  {"http2_put", nasl_http2_put},
   {"add_host_name", add_hostname},
   {"get_host_name", get_hostname},
+  {"ip_reverse_lookup", host_reverse_lookup},
   {"get_host_names", get_hostnames},
   {"get_host_name_source", get_hostname_source},
   {"resolve_host_name", resolve_hostname},
@@ -345,8 +358,8 @@ static init_func libfuncs[] = {
   {"ssh_get_server_banner", nasl_ssh_get_server_banner},
   {"ssh_get_auth_methods", nasl_ssh_get_auth_methods},
   {"ssh_get_host_key", nasl_ssh_get_host_key},
+  {"ssh_execute_netconf_subsystem", nasl_ssh_execute_netconf_subsystem},
   {"sftp_enabled_check", nasl_sftp_enabled_check},
-
 #ifdef HAVE_LIBKSBA
   {"cert_open", nasl_cert_open},
   {"cert_close", nasl_cert_close},
@@ -403,6 +416,18 @@ static init_func libfuncs[] = {
   {"isotime_scan", nasl_isotime_scan},
   {"isotime_print", nasl_isotime_print},
   {"isotime_add", nasl_isotime_add},
+  // krb5
+  {"krb5_find_kdc", nasl_okrb5_find_kdc},
+  {"krb5_is_success", nasl_okrb5_is_success},
+  {"krb5_is_failure", nasl_okrb5_is_failure},
+  {"krb5_gss_init", nasl_okrb5_gss_init},
+  {"krb5_gss_prepare_context", nasl_okrb5_gss_prepare_context},
+  {"krb5_gss_update_context", nasl_okrb5_gss_update_context},
+  {"krb5_gss_update_context_needs_more",
+   nasl_okrb5_gss_update_context_needs_more},
+  {"krb5_gss_update_context_out", nasl_okrb5_gss_update_context_out},
+  {"krb5_gss_session_key", nasl_okrb5_gss_session_key_context},
+  {"krb5_error_code_to_string", nasl_okrb5_error_code_to_string},
   {NULL, NULL}};
 
 /* String variables */
@@ -539,7 +564,7 @@ func_is_internal (const char *name)
 }
 
 char *
-nasl_version ()
+nasl_version (void)
 {
   static char vers[sizeof (OPENVASLIB_VERSION) + 1];
   strncpy (vers, OPENVASLIB_VERSION, sizeof (vers) - 1);
