@@ -1,20 +1,6 @@
-/* Copyright (C) 2014-2022 Greenbone Networks GmbH
+/* SPDX-FileCopyrightText: 2023 Greenbone AG
  *
  * SPDX-License-Identifier: GPL-2.0-or-later
- *
- * This program is free software; you can redistribute it and/or
- * modify it under the terms of the GNU General Public License
- * as published by the Free Software Foundation; either version 2
- * of the License, or (at your option) any later version.
- *
- * This program is distributed in the hope that it will be useful,
- * but WITHOUT ANY WARRANTY; without even the implied warranty of
- * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
- * GNU General Public License for more details.
- *
- * You should have received a copy of the GNU General Public License
- * along with this program; if not, write to the Free Software
- * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA 02110-1301 USA.
  */
 
 /**
@@ -312,8 +298,14 @@ snmpv3_get (const snmpv3_request_t request, snmp_result_t result)
         }
       else
         {
+#ifdef NETSNMP_DISABLE_DES
+          result->name =
+            g_strdup ("DES not supported in this net-snmp version.");
+          return -1;
+#else
           session.securityPrivProto = usmDESPrivProtocol;
           session.securityPrivProtoLen = USM_PRIV_PROTO_DES_LEN;
+#endif
         }
       session.securityPrivKeyLen = USM_PRIV_KU_LEN;
       if (generate_Ku (session.securityAuthProto, session.securityAuthProtoLen,
