@@ -3,16 +3,16 @@
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
 use crate::function_set;
+#[cfg(feature = "nasl-c-lib")]
+use crate::nasl::prelude::*;
 
 /// NASL function to calculate GMAC with AES128.
 ///
 /// This function expects 3 named arguments key, data and iv either in a string or data type.
 #[cfg(feature = "nasl-c-lib")]
-fn aes_gmac(
-    register: &crate::nasl::utils::Register,
-    _: &crate::nasl::utils::Context,
-) -> Result<crate::nasl::syntax::NaslValue, crate::nasl::utils::FunctionErrorKind> {
-    use super::{get_data, get_iv, get_key};
+#[nasl_function]
+fn aes_gmac(register: &Register) -> Result<NaslValue, FnError> {
+    use super::{CryptographicError, get_data, get_iv, get_key};
     use nasl_c_lib::cryptographic::mac::aes_gmac;
 
     let key = get_key(register)?;
@@ -21,12 +21,7 @@ fn aes_gmac(
 
     match aes_gmac(data, key, iv) {
         Ok(val) => Ok(val.into()),
-        Err(code) => Err(crate::nasl::utils::FunctionErrorKind::GeneralError(
-            crate::nasl::utils::error::GeneralErrorType::UnexpectedData(format!(
-                "Error code {}",
-                code
-            )),
-        )),
+        Err(msg) => Err(CryptographicError::AesGmacError(msg.into()).into()),
     }
 }
 
@@ -35,7 +30,6 @@ pub struct AesGmac;
 #[cfg(feature = "nasl-c-lib")]
 function_set! {
     AesGmac,
-    sync_stateless,
     (
         aes_gmac
     )
@@ -44,7 +38,6 @@ function_set! {
 #[cfg(not(feature = "nasl-c-lib"))]
 function_set! {
     AesGmac,
-    sync_stateless,
     (
     )
 }
