@@ -11,8 +11,7 @@ use std::{net::Ipv4Addr, str::FromStr};
 
 use pcap::{Capture, Device};
 
-use super::super::host::get_host_ip;
-
+use super::RawIpError;
 use super::raw_ip_utils::{get_interface_by_local_ip, get_source_ip, ipstr2ipaddr};
 
 use tracing::info;
@@ -105,11 +104,11 @@ impl From<&Frame> for Vec<u8> {
 }
 
 impl TryFrom<&[u8]> for Frame {
-    type Error = FunctionErrorKind;
+    type Error = FnError;
 
     fn try_from(f: &[u8]) -> Result<Self, Self::Error> {
         if f.len() < 14 {
-            Err(FunctionErrorKind::missing_argument("valid ip address"))
+            Err(FnError::missing_argument("valid ip address"))
         } else {
             let mut frame = Frame::new();
             frame.set_dsthaddr(MacAddr(f[0], f[1], f[2], f[3], f[4], f[5]));
@@ -272,28 +271,27 @@ fn convert_vec_into_mac_address(v: &[u8]) -> Option<MacAddr> {
     }
 }
 
-fn validate_mac_address(v: Option<&ContextType>) -> Result<MacAddr, FunctionErrorKind> {
+fn validate_mac_address(v: Option<&ContextType>) -> Result<MacAddr, FnError> {
     let mac_addr = match v {
         Some(ContextType::Value(NaslValue::String(x))) => MacAddr::from_str(x).ok(),
         Some(ContextType::Value(NaslValue::Data(x))) => convert_vec_into_mac_address(x),
         _ => None,
     };
-    mac_addr.ok_or_else(|| {
-        FunctionErrorKind::wrong_unnamed_argument("mac address", "invalid mac address")
-    })
+    mac_addr.ok_or_else(|| FnError::wrong_unnamed_argument("mac address", "invalid mac address"))
 }
 
 /// Return the MAC address, given the interface name
-fn get_local_mac_address(name: &str) -> Option<MacAddr> {
-    match interfaces().into_iter().find(|x| x.name == *name) {
-        Some(dev) => dev.mac,
-        _ => None,
-    }
+fn get_local_mac_address(name: &str) -> Result<MacAddr, FnError> {
+    interfaces()
+        .into_iter()
+        .find(|x| x.name == *name)
+        .and_then(|dev| dev.mac)
+        .ok_or_else(|| RawIpError::FailedToGetLocalMacAddress.into())
 }
 
 /// Return a frame given a capture device and a filter. It returns an empty frame in case
 /// there was no response or anything was filtered.
-fn recv_frame(cap: &mut Capture<pcap::Active>, filter: &str) -> Result<Frame, FunctionErrorKind> {
+fn recv_frame(cap: &mut Capture<pcap::Active>, filter: &str) -> Result<Frame, FnError> {
     let f = Frame::new();
 
     let p = match cap.filter(filter, true) {
@@ -313,7 +311,7 @@ fn send_frame(
     pcap_active: &bool,
     filter: Option<&String>,
     timeout: i32,
-) -> Result<Option<Frame>, FunctionErrorKind> {
+) -> Result<Option<Frame>, FnError> {
     let mut capture_dev = match Capture::from_device(iface.clone()) {
         Ok(c) => match c.promisc(true).timeout(timeout).open() {
             Ok(mut capture) => match capture.sendpacket(frame) {
@@ -346,55 +344,46 @@ fn send_frame(
 ///  
 /// It takes the following argument:
 /// - cap_timeout: time to wait for answer in seconds, 5 by default
-fn nasl_send_arp_request(
-    register: &Register,
-    context: &Context,
-) -> Result<NaslValue, FunctionErrorKind> {
+#[nasl_function]
+fn nasl_send_arp_request(register: &Register, context: &Context) -> Result<NaslValue, FnError> {
     let timeout = match register.named("pcap_timeout") {
         Some(ContextType::Value(NaslValue::Number(x))) => *x as i32 * 1000i32, // to milliseconds
         None => DEFAULT_TIMEOUT,
         _ => {
-            return Err(FunctionErrorKind::wrong_unnamed_argument(
+            return Err(FnError::wrong_unnamed_argument(
                 "Integer",
                 "Invalid timeout value",
-            ))
+            ));
         }
     };
 
-    let target_ip = get_host_ip(context)?;
+    let target_ip = context.target().ip_addr();
 
     if target_ip.is_ipv6() {
-        return Err(FunctionErrorKind::wrong_unnamed_argument(
+        return Err(FnError::wrong_unnamed_argument(
             "IPv4",
             "IPv6 does not support ARP protocol.",
         ));
     }
-    let local_ip = get_source_ip(target_ip, 50000u16)?;
+    let local_ip = get_source_ip(target_ip)?;
     let iface = get_interface_by_local_ip(local_ip)?;
-    let local_mac_address = match get_local_mac_address(&iface.name) {
-        Some(x) => x,
-        _ => {
-            return Err(FunctionErrorKind::missing_argument(
-                "Not possible to get a src mac address.",
-            ))
-        }
-    };
+    let local_mac_address = get_local_mac_address(&iface.name)?;
 
     let src_ip = match Ipv4Addr::from_str(&local_ip.to_string()) {
         Ok(x) => x,
         Err(_) => {
-            return Err(FunctionErrorKind::missing_argument(
+            return Err(FnError::missing_argument(
                 "Not possible to parse the src IP address.",
-            ))
+            ));
         }
     };
 
     let dst_ip = match Ipv4Addr::from_str(&target_ip.to_string()) {
         Ok(x) => x,
         Err(_) => {
-            return Err(FunctionErrorKind::missing_argument(
+            return Err(FnError::missing_argument(
                 "Not possible to parse the dst IP address.",
-            ))
+            ));
         }
     };
 
@@ -409,33 +398,27 @@ fn nasl_send_arp_request(
 
 /// Get the MAC address of a local IP address.
 /// The first positional argument is a local IP address as string.
-fn nasl_get_local_mac_address_from_ip(
-    register: &Register,
-    _: &Context,
-) -> Result<NaslValue, FunctionErrorKind> {
+#[nasl_function]
+fn nasl_get_local_mac_address_from_ip(register: &Register) -> Result<NaslValue, FnError> {
     let positional = register.positional();
     if positional.is_empty() {
-        return Err(FunctionErrorKind::MissingPositionalArguments {
+        return Err(ArgumentError::MissingPositionals {
             expected: 1,
             got: 0,
-        });
+        }
+        .into());
     }
 
     match &positional[0] {
         NaslValue::String(x) => {
             let ip = ipstr2ipaddr(x)?;
             let iface = get_interface_by_local_ip(ip)?;
-            match get_local_mac_address(&iface.name) {
-                Some(mac) => Ok(NaslValue::String(mac.to_string())),
-                _ => Err(FunctionErrorKind::Diagnostic(
-                    "Not possible to get the local mac address".to_string(),
-                    Some(NaslValue::Null),
-                )),
-            }
+            get_local_mac_address(&iface.name).map(|mac| mac.to_string().into())
         }
-        _ => Err(FunctionErrorKind::WrongArgument(
+        _ => Err(ArgumentError::WrongArgument(
             "Expected String containing a valid IP address.".to_string(),
-        )),
+        )
+        .into()),
     }
 }
 
@@ -445,7 +428,8 @@ fn nasl_get_local_mac_address_from_ip(
 /// - ether_proto: is an int containing the ethernet type (normally given as hexadecimal).
 ///   It is optional and its default value is 0x0800. A list of Types can be e.g. looked up here.
 /// - payload: is any data, which is then attached as payload to the frame.
-fn nasl_forge_frame(register: &Register, _: &Context) -> Result<NaslValue, FunctionErrorKind> {
+#[nasl_function]
+fn nasl_forge_frame(register: &Register) -> Result<NaslValue, FnError> {
     let src_haddr = validate_mac_address(register.named("src_haddr"))?;
     let dst_haddr = validate_mac_address(register.named("dst_haddr"))?;
     let ether_proto = match register.named("ether_proto") {
@@ -473,25 +457,21 @@ fn nasl_forge_frame(register: &Register, _: &Context) -> Result<NaslValue, Funct
 /// - pcap_active: option to capture the answer, default is TRUE
 /// - pcap_filter: filter for the answer
 /// - pcap_timeout: time to wait for the answer in seconds, default 5
-fn nasl_send_frame(register: &Register, context: &Context) -> Result<NaslValue, FunctionErrorKind> {
+#[nasl_function]
+fn nasl_send_frame(register: &Register, context: &Context) -> Result<NaslValue, FnError> {
     let frame = match register.named("frame") {
         Some(ContextType::Value(NaslValue::Data(x))) => x,
-        _ => {
-            return Err(FunctionErrorKind::wrong_unnamed_argument(
-                "Data",
-                "Invalid data type",
-            ))
-        }
+        _ => return Err(FnError::wrong_unnamed_argument("Data", "Invalid data type")),
     };
 
     let pcap_active = match register.named("pcap_active") {
         Some(ContextType::Value(NaslValue::Boolean(x))) => x,
         None => &true,
         _ => {
-            return Err(FunctionErrorKind::wrong_unnamed_argument(
+            return Err(FnError::wrong_unnamed_argument(
                 "Boolean",
                 "Invalid pcap_active value",
-            ))
+            ));
         }
     };
 
@@ -499,10 +479,10 @@ fn nasl_send_frame(register: &Register, context: &Context) -> Result<NaslValue,
         Some(ContextType::Value(NaslValue::String(x))) => Some(x),
         None => None,
         _ => {
-            return Err(FunctionErrorKind::wrong_unnamed_argument(
+            return Err(FnError::wrong_unnamed_argument(
                 "String",
                 "Invalid pcap_filter value",
-            ))
+            ));
         }
     };
 
@@ -510,16 +490,16 @@ fn nasl_send_frame(register: &Register, context: &Context) -> Result<NaslValue,
         Some(ContextType::Value(NaslValue::Number(x))) => *x as i32 * 1000i32, // to milliseconds
         None => DEFAULT_TIMEOUT,
         _ => {
-            return Err(FunctionErrorKind::wrong_unnamed_argument(
+            return Err(FnError::wrong_unnamed_argument(
                 "Integer",
                 "Invalid timeout value",
-            ))
+            ));
         }
     };
 
-    let target_ip = get_host_ip(context)?;
+    let target_ip = context.target().ip_addr();
 
-    let local_ip = get_source_ip(target_ip, 50000u16)?;
+    let local_ip = get_source_ip(target_ip)?;
     let iface = get_interface_by_local_ip(local_ip)?;
 
     // send the frame and get a response if pcap_active enabled
@@ -532,15 +512,11 @@ fn nasl_send_frame(register: &Register, context: &Context) -> Result<NaslValue,
 /// Print a datalink layer frame in its hexadecimal representation.
 /// The named argument frame is a string representing the datalink layer frame. A frame can be created with forge_frame(3).
 /// This function is meant to be used for debugging.
-fn nasl_dump_frame(register: &Register, _: &Context) -> Result<NaslValue, FunctionErrorKind> {
+#[nasl_function]
+fn nasl_dump_frame(register: &Register) -> Result<NaslValue, FnError> {
     let frame: Frame = match register.named("frame") {
         Some(ContextType::Value(NaslValue::Data(x))) => (x as &[u8]).try_into()?,
-        _ => {
-            return Err(FunctionErrorKind::wrong_unnamed_argument(
-                "Data",
-                "Invalid data type",
-            ))
-        }
+        _ => return Err(FnError::wrong_unnamed_argument("Data", "Invalid data type")),
     };
 
     info!(frame=%frame);
@@ -573,7 +549,6 @@ pub struct FrameForgery;
 
 function_set! {
     FrameForgery,
-    sync_stateless,
     (
         (nasl_send_frame, "send_frame"),
         (nasl_dump_frame, "dump_frame"),
@@ -613,9 +588,9 @@ mod tests {
     #[test]
     fn get_local_mac() {
         if cfg!(target_os = "macos") {
-            assert_eq!(get_local_mac_address("lo"), None);
+            assert!(matches!(get_local_mac_address("lo"), Err(_)));
         } else {
-            assert_eq!(get_local_mac_address("lo"), Some(MacAddr::zero()));
+            assert_eq!(get_local_mac_address("lo").unwrap(), MacAddr::zero());
         }
     }
 }
