@@ -3,11 +3,11 @@
 // SPDX-License-Identifier: GPL-2.0-or-later WITH x11vnc-openssl-exception
 
 use super::{
+    ErrorKind, Statement, StatementKind,
     error::SyntaxError,
     grouping_extension::Grouping,
     lexer::{End, Lexer},
     token::{Category, IdentifierType, Token},
-    ErrorKind, Statement, StatementKind,
 };
 use crate::{
     unclosed_statement, unclosed_token, unexpected_end, unexpected_statement, unexpected_token,
@@ -22,7 +22,7 @@ pub(crate) trait Keywords {
     ) -> Result<(End, Statement), SyntaxError>;
 }
 
-impl<'a> Lexer<'a> {
+impl Lexer<'_> {
     fn parse_declaration(&mut self, token: Token) -> Result<Statement, SyntaxError> {
         let (end, params) = self.parse_comma_group(Category::Semicolon)?;
         match end {
@@ -425,7 +425,7 @@ impl<'a> Lexer<'a> {
     }
 }
 
-impl<'a> Keywords for Lexer<'a> {
+impl Keywords for Lexer<'_> {
     fn parse_keyword(
         &mut self,
         keyword: IdentifierType,
@@ -491,9 +491,8 @@ impl<'a> Keywords for Lexer<'a> {
 mod test {
 
     use super::super::{
-        parse,
+        Statement, parse,
         token::{Category, IdentifierType},
-        Statement,
     };
 
     use super::super::StatementKind::*;
@@ -714,9 +713,11 @@ mod test {
         assert!(parse("local_var a, 1, c;").next().unwrap().is_err());
         assert!(parse("local_var 1;").next().unwrap().is_err());
         assert!(parse("if (description) { ; ").next().unwrap().is_err());
-        assert!(parse("if (description) display(1)")
-            .next()
-            .unwrap()
-            .is_err());
+        assert!(
+            parse("if (description) display(1)")
+                .next()
+                .unwrap()
+                .is_err()
+        );
     }
 }
