@@ -6,11 +6,15 @@
 use std::fmt::Display;
 use std::ops::Range;
 
+#[cfg(test)]
+use serde::{Deserialize, Serialize};
+
 use super::cursor::Cursor;
-use crate::storage::item::ACT;
+use crate::{nasl::interpreter::InterpretError, storage::items::nvt::ACT};
 
 /// Identifies if number is base10, base 8, hex or binary
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
+#[cfg_attr(test, derive(Serialize, Deserialize))]
 pub enum Base {
     /// Base 2: contains 01 is defined by 0b e.g.: `0b010101`
     Binary,
@@ -60,6 +64,7 @@ impl Base {
 
 /// Is used to identify which Category type is unclosed
 #[derive(Clone, Copy, Debug, PartialEq, Eq)]
+#[cfg_attr(test, derive(Serialize, Deserialize))]
 pub enum UnclosedCategory {
     /// Is a unclosed String.
     String,
@@ -121,6 +126,7 @@ impl Display for IdentifierType {
 
 /// Unless Dynamic those are reserved words that cannot be reused otherwise.
 #[derive(Clone, Debug, PartialEq, Eq)]
+#[cfg_attr(test, derive(Serialize, Deserialize))]
 pub enum IdentifierType {
     /// function declaration
     Function,
@@ -201,6 +207,7 @@ make_keyword_matcher! {
 
 /// Is used to identify a Token
 #[derive(Clone, Debug, PartialEq, Eq)]
+#[cfg_attr(test, derive(Serialize, Deserialize))]
 pub enum Category {
     /// `(`
     LeftParen,
@@ -396,6 +403,7 @@ impl Display for Category {
 
 #[derive(Clone, Debug, PartialEq, Eq)]
 /// Contains the TokenType as well as the position.
+#[cfg_attr(test, derive(Serialize, Deserialize))]
 pub struct Token {
     /// The category or kind of a token
     pub category: Category,
@@ -424,15 +432,18 @@ impl Token {
             position: (0, 0),
         }
     }
+
+    pub fn identifier(&self) -> Result<String, InterpretError> {
+        match self.category() {
+            Category::Identifier(IdentifierType::Undefined(x)) => Ok(x.to_owned()),
+            cat => Err(InterpretError::wrong_category(cat)),
+        }
+    }
 }
 
 impl Display for Token {
     fn fmt(&self, f: &mut std::fmt::Formatter<'_>) -> std::fmt::Result {
-        write!(
-            f,
-            "{}:{} {}",
-            self.line_column.0, self.line_column.1, self.category
-        )
+        write!(f, "'{}'", self.category,)
     }
 }
 
@@ -442,6 +453,16 @@ impl Token {
         &self.category
     }
 
+    /// Returns the line number of the token
+    pub fn line(&self) -> usize {
+        self.line_column.0
+    }
+
+    /// Returns the column number of the token
+    pub fn column(&self) -> usize {
+        self.line_column.1
+    }
+
     /// Returns true when an Token is faulty
     ///
     /// A Token is faulty when it is a syntactical error like
@@ -743,7 +764,7 @@ macro_rules! two_symbol_token {
     };
 }
 
-impl<'a> Iterator for Tokenizer<'a> {
+impl Iterator for Tokenizer<'_> {
     type Item = Token;
 
     fn next(&mut self) -> Option<Self::Item> {
