@@ -9,7 +9,7 @@ use std::{
     time::Duration,
 };
 
-use clap::{builder::TypedValueParser, ArgAction};
+use clap::{ArgAction, builder::TypedValueParser};
 use serde::{Deserialize, Serialize};
 
 #[derive(Deserialize, Serialize, Debug, Clone)]
@@ -199,6 +199,8 @@ impl TypedValueParser for Mode {
 pub struct Endpoints {
     pub enable_get_scans: bool,
     #[serde(default)]
+    pub enable_get_performance: Option<bool>,
+    #[serde(default)]
     pub key: Option<String>,
 }
 
@@ -333,9 +335,10 @@ impl Config {
 
     fn from_file<P>(path: P) -> Self
     where
-        P: AsRef<std::path::Path> + std::fmt::Display,
+        P: AsRef<std::path::Path> + std::fmt::Display + std::fmt::Debug,
     {
-        let config = std::fs::read_to_string(path).unwrap();
+        let config = std::fs::read_to_string(&path)
+            .unwrap_or_else(|e| panic!("Failed to read openvasd config from file: {path:?}. {e}"));
         toml::from_str(&config).unwrap()
     }
 
@@ -427,6 +430,15 @@ impl Config {
                     .default_missing_value("true")
                     .help("enable get scans endpoint. Default 'true'."),
             )
+            .arg(
+                clap::Arg::new("enable-get-performance")
+                    .env("ENABLE_GET_PERFORMANCE")
+                    .long("enable-get-performance")
+                    .num_args(0..=1)
+                    .value_parser(clap::builder::BoolValueParser::new())
+                    .default_missing_value("false")
+                    .help("enable get performance endpoint. Default 'false'."),
+            )
             .arg(
                 clap::Arg::new("api-key")
                     .env("API_KEY")
@@ -602,6 +614,9 @@ impl Config {
         if let Some(enable) = cmds.get_one::<bool>("enable-get-scans") {
             config.endpoints.enable_get_scans = *enable;
         }
+        if let Some(enable) = cmds.get_one::<bool>("enable-get-performance") {
+            config.endpoints.enable_get_performance = Some(*enable);
+        }
         if let Some(api_key) = cmds.get_one::<String>("api-key") {
             config.endpoints.key = Some(api_key.clone());
         }
@@ -646,6 +661,7 @@ mod tests {
         assert_eq!(config.feed.check_interval, Duration::from_secs(3600));
 
         assert!(!config.endpoints.enable_get_scans);
+        assert!(config.endpoints.enable_get_performance.is_none());
         assert!(config.endpoints.key.is_none());
 
         assert!(config.tls.certs.is_none());
