@@ -11,7 +11,7 @@ use async_trait::async_trait;
 use scannerlib::models::scanner::Error as ScanError;
 use scannerlib::models::scanner::{ScanResultFetcher, ScanResults, ScanStopper};
 use scannerlib::models::{Phase, Scan, Status};
-use scannerlib::storage::item::Nvt;
+use scannerlib::storage::items::nvt::Nvt;
 use tokio::sync::RwLock;
 
 use crate::{
@@ -170,13 +170,16 @@ where
 
     pub async fn delete_scan_by_id(&self, id: &str) -> Result<(), Error> {
         let mut queued = self.queued.write().await;
-        if let Some(idx) = queued.iter().position(|x| x == id) {
-            queued.swap_remove(idx);
-        } else {
-            let mut running = self.running.write().await;
-            if let Some(idx) = running.iter().position(|x| x == id) {
-                self.scanner.stop_scan(id.to_string()).await?;
-                running.swap_remove(idx);
+        match queued.iter().position(|x| x == id) {
+            Some(idx) => {
+                queued.swap_remove(idx);
+            }
+            _ => {
+                let mut running = self.running.write().await;
+                if let Some(idx) = running.iter().position(|x| x == id) {
+                    self.scanner.stop_scan(id.to_string()).await?;
+                    running.swap_remove(idx);
+                }
             }
         }
 
@@ -204,40 +207,43 @@ where
 
         tracing::trace!(%amount_to_start, "handling scans");
         for _ in 0..amount_to_start {
-            if let Some(scan_id) = queued.pop() {
-                let (scan, status) = self.db.get_decrypted_scan(&scan_id).await?;
-                if !self.scanner.can_start_scan(&scan).await {
-                    tracing::debug!(?status, %scan_id, "unable to start scan");
-                    queued.push(scan_id);
-                } else {
-                    tracing::debug!(?status, %scan_id, "starting scan");
-                    match self.scanner.start_scan(scan).await {
-                        Ok(_) => {
-                            tracing::debug!(%scan_id, "started");
-                            running.push(scan_id.clone());
-                        }
-                        Err(ScanError::Connection(e)) => {
-                            tracing::warn!(%scan_id, %e, "requeuing because of a connection error");
-                            queued.push(scan_id);
-                        }
-                        Err(e) => {
-                            tracing::warn!(%scan_id, %e, "unable to start, removing from queue and set status to failed. Verify that scan using the API");
-                            self.db
-                                .update_status(
-                                    &scan_id,
-                                    Status {
-                                        start_time: None,
-                                        end_time: None,
-                                        status: Phase::Failed,
-                                        host_info: None,
-                                    },
-                                )
-                                .await?;
-                        }
-                    };
+            match queued.pop() {
+                Some(scan_id) => {
+                    let (scan, status) = self.db.get_decrypted_scan(&scan_id).await?;
+                    if !self.scanner.can_start_scan(&scan).await {
+                        tracing::debug!(?status, %scan_id, "unable to start scan");
+                        queued.push(scan_id);
+                    } else {
+                        tracing::debug!(?status, %scan_id, "starting scan");
+                        match self.scanner.start_scan(scan).await {
+                            Ok(_) => {
+                                tracing::debug!(%scan_id, "started");
+                                running.push(scan_id.clone());
+                            }
+                            Err(ScanError::Connection(e)) => {
+                                tracing::warn!(%scan_id, %e, "requeuing because of a connection error");
+                                queued.push(scan_id);
+                            }
+                            Err(e) => {
+                                tracing::warn!(%scan_id, %e, "unable to start, removing from queue and set status to failed. Verify that scan using the API");
+                                self.db
+                                    .update_status(
+                                        &scan_id,
+                                        Status {
+                                            start_time: None,
+                                            end_time: None,
+                                            status: Phase::Failed,
+                                            host_info: None,
+                                        },
+                                    )
+                                    .await?;
+                            }
+                        };
+                    }
+                }
+                _ => {
+                    break;
                 }
-            } else {
-                break;
             }
         }
         Ok(())
@@ -445,11 +451,11 @@ where
         result
     }
 
-    async fn oids(&self) -> Result<Box<dyn Iterator<Item = String> + Send>, StorageError> {
+    async fn oids(&self) -> Result<Vec<String>, StorageError> {
         self.db.oids().await
     }
 
-    async fn vts<'a>(&self) -> Result<Box<dyn Iterator<Item = Nvt> + Send + 'a>, StorageError> {
+    async fn vts<'a>(&self) -> Result<Vec<Nvt>, StorageError> {
         self.db.vts().await
     }
 
@@ -526,13 +532,13 @@ mod tests {
     use crate::{
         config,
         scheduling::{self, Scheduler},
-        storage::{inmemory, ScanStorer as _},
+        storage::{ScanStorer as _, inmemory},
     };
 
     mod synchronize {
         use scannerlib::models::{
-            scanner::{self, Lambda, LambdaBuilder, ScanResults, ScanStopper as _},
             Phase, Status,
+            scanner::{self, Lambda, LambdaBuilder, ScanResults, ScanStopper as _},
         };
 
         use super::*;
@@ -540,8 +546,7 @@ mod tests {
         #[traced_test]
         #[tokio::test]
         async fn set_running() {
-            let scans = std::iter::repeat(Scan::default())
-                .take(10)
+            let scans = std::iter::repeat_n(Scan::default(), 10)
                 .map(|x| {
                     let mut y = x.clone();
                     y.scan_id = uuid::Uuid::new_v4().to_string();
@@ -566,8 +571,7 @@ mod tests {
         #[traced_test]
         #[tokio::test]
         async fn not_move_from_queue_on_max_running() {
-            let scans = std::iter::repeat(Scan::default())
-                .take(10)
+            let scans = std::iter::repeat_n(Scan::default(), 10)
                 .map(|x| {
                     let mut y = x.clone();
                     y.scan_id = uuid::Uuid::new_v4().to_string();
@@ -602,8 +606,7 @@ mod tests {
         #[traced_test]
         #[tokio::test]
         async fn not_move_from_queue_on_insufficient_memory() {
-            let scans = std::iter::repeat(Scan::default())
-                .take(10)
+            let scans = std::iter::repeat_n(Scan::default(), 10)
                 .map(|x| {
                     let mut y = x.clone();
                     y.scan_id = uuid::Uuid::new_v4().to_string();
@@ -629,8 +632,7 @@ mod tests {
         #[traced_test]
         #[tokio::test]
         async fn not_move_from_queue_on_connection_error() {
-            let scans = std::iter::repeat(Scan::default())
-                .take(10)
+            let scans = std::iter::repeat_n(Scan::default(), 10)
                 .map(|x| {
                     let mut y = x.clone();
                     y.scan_id = uuid::Uuid::new_v4().to_string();
@@ -662,8 +664,7 @@ mod tests {
         #[traced_test]
         #[tokio::test]
         async fn remove_from_queue_on_any_other_scan_error() {
-            let scans = std::iter::repeat(Scan::default())
-                .take(10)
+            let scans = std::iter::repeat_n(Scan::default(), 10)
                 .map(|x| {
                     let mut y = x.clone();
                     y.scan_id = uuid::Uuid::new_v4().to_string();
@@ -691,8 +692,7 @@ mod tests {
         #[traced_test]
         #[tokio::test]
         async fn remove_from_running_when_stop() {
-            let scans = std::iter::repeat(Scan::default())
-                .take(10)
+            let scans = std::iter::repeat_n(Scan::default(), 10)
                 .map(|x| {
                     let mut y = x.clone();
                     y.scan_id = uuid::Uuid::new_v4().to_string();
@@ -721,8 +721,7 @@ mod tests {
         #[traced_test]
         #[tokio::test]
         async fn remove_from_running_when_finished() {
-            let scans = std::iter::repeat(Scan::default())
-                .take(10)
+            let scans = std::iter::repeat_n(Scan::default(), 10)
                 .map(|x| {
                     let mut y = x.clone();
                     y.scan_id = uuid::Uuid::new_v4().to_string();
@@ -764,7 +763,7 @@ mod tests {
     }
 
     mod start {
-        use scannerlib::models::{scanner::Lambda, Phase};
+        use scannerlib::models::{Phase, scanner::Lambda};
 
         use crate::storage::ProgressGetter;
 
